% -------------------------------------------------------------------------
% @ ver 1.0, Sept. 18, 2010, Jonathan P. Fiene, Univ. of Pennsylvania
% -------------------------------------------------------------------------
% Call this routine to initialize a Phidget 1061 or 1066 servo board.  The
% board must be connected for this to work.  Do not forget to call
% servoRelease before disconnecting the device from the computer!
%
% Note: Upon initialization, the run state is set to disabled (see
% servoRun).
% -------------------------------------------------------------------------
% startServo
% -------------------------------------------------------------------------

warning off all;

if exist('Shandle','var')
    disp('Nothing done - Phidget Servo already started')
else
    global Shandle;
    if ~libisloaded('phidget21')
        loadlibrary phidget21 phidget21Matlab.h;
    end
    ptr = libpointer('int32Ptr',0);
    calllib('phidget21', 'CPhidgetAdvancedServo_create', ptr);
    Shandle = get(ptr, 'Value');

    % try to connect to our servo controller
    calllib('phidget21', 'CPhidget_open', Shandle, -1);
    if calllib('phidget21', 'CPhidget_waitForAttachment', Shandle, 2500) == 0
   
        % determine the number of channels on the board
        valPtr = libpointer('int32Ptr', 0);
        calllib('phidget21', 'CPhidgetAdvancedServo_getMotorCount', Shandle, valPtr);
        motorCount = get(valPtr, 'Value');
        valPtr = libpointer('doublePtr', 0);
        for(i=0:motorCount-1)
            % set velocity limit to max velocity
            calllib('phidget21', 'CPhidgetAdvancedServo_getVelocityMax', Shandle, i, valPtr);
            maxVelocity = get(valPtr, 'Value');
            calllib('phidget21', 'CPhidgetAdvancedServo_setVelocityLimit', Shandle, i, maxVelocity);

            % set acceleration limit to max acceleration
            calllib('phidget21', 'CPhidgetAdvancedServo_getAccelerationMax', Shandle, i, valPtr);
            maxAccel = get(valPtr, 'Value');
            calllib('phidget21', 'CPhidgetAdvancedServo_setAcceleration', Shandle, i, maxAccel);

            % disable speed ramping
            calllib('phidget21', 'CPhidgetAdvancedServo_setSpeedRampingOn', Shandle, i, 0);
        end
        disp('Phidget Servo start: SUCCESS')
        pause(0.1)
    else
        calllib('phidget21', 'CPhidget_close', Shandle);
        calllib('phidget21', 'CPhidget_delete', Shandle);

        unloadlibrary phidget21;
        clear Shandle ptr;
        
        fprintf(2,'Phidget Servo start: FAIL!\nTruly sorry about that.\nPerhaps you should check your cables.\n')
    end
end

warning on all;