function [current] = servoCurrent(channel)
% -------------------------------------------------------------------------
% @ ver 1.0, Sept. 18, 2010, Jonathan P. Fiene, Univ. of Pennsylvania
% -------------------------------------------------------------------------
% Use this function to read the current being consumed by a particular servo.
% -------------------------------------------------------------------------
% [current] = servoCurrent(channel)
%
% channel  = 0 (for the Phidget 1066 single-servo board)
%            0-7 (for the Phidget 1061 eight-servo board)
%
% current = the measured current value
% -------------------------------------------------------------------------

global Shandle;

% check to see if the board has that channel:
valPtr = libpointer('int32Ptr', 0);
calllib('phidget21', 'CPhidgetAdvancedServo_getMotorCount', Shandle, valPtr);
motorCount = get(valPtr, 'Value');
if(channel >= motorCount || channel < 0)
    if motorCount == 1
        fprintf(2,'ERROR in servoCurrent():  The Phidget 1066 board only supports channel 0.\n');
    else
        fprintf(2,'ERROR in servoCurrent():  The Phidget 1061 board only supports channels 0-7.\n');
    end
else
    valPtr = libpointer('doublePtr', 0);
    calllib('phidget21', 'CPhidgetAdvancedServo_getCurrent', Shandle, channel, valPtr);
    current = get(valPtr, 'Value');
end