function [] = servoLimits(channel,min,max)
% -------------------------------------------------------------------------
% @ ver 1.0, Sept. 18, 2010, Jonathan P. Fiene, Univ. of Pennsylvania
% -------------------------------------------------------------------------
% Use this function to override the position limits for a particular servo.
% -------------------------------------------------------------------------
% servoLimits(channel, min, max)
%
% channel = 0 (for the Phidget 1066 single-servo board)
%           0-7 (for the Phidget 1061 eight-servo board)
%
%     min = minimum value - must be greater than -22.99218
%
%     max = maximum value - must be less than 233
% -------------------------------------------------------------------------

global Shandle;

% check to see if the board has that channel:
valPtr = libpointer('int32Ptr', 0);
calllib('phidget21', 'CPhidgetAdvancedServo_getMotorCount', Shandle, valPtr);
motorCount = get(valPtr, 'Value');
if(channel >= motorCount || channel < 0)
    if motorCount == 1
        fprintf(2,'ERROR in servoLimits():  The Phidget 1066 board only supports channel 0.\n');
    else
        fprintf(2,'ERROR in servoLimits():  The Phidget 1061 board only supports channels 0-7.\n');
    end
else  
    if max > min
        if max < 233
            calllib('phidget21', 'CPhidgetAdvancedServo_setPositionMax', Shandle, channel, max);
        else
            fprintf(2,'ERROR in servoLimits():  Max must be less than 233\n');
        end
        if min > -22.99218
            calllib('phidget21', 'CPhidgetAdvancedServo_setPositionMin', Shandle, channel, min);
        else
            fprintf(2,'ERROR in servoLimits():  Min must be greater than -22.99218\n');
        end
    else
        fprintf(2,'ERROR in servoLimits():  Max must be greater than Min!\n');
    end
end