function [] = servoRun(channel)
% -------------------------------------------------------------------------
% @ ver 1.0, Sept. 18, 2010, Jonathan P. Fiene, Univ. of Pennsylvania
% -------------------------------------------------------------------------
% Use this function to enable the output of a particular servo.
%
% Note:  If a servo is enabled and the desire position is different from 
% the actual, the servo will snap to the desired position.
% -------------------------------------------------------------------------
% servoRun(channel, state)
%
% channel = 0 (for the Phidget 1066 single-servo board)
%           0-7 (for the Phidget 1061 eight-servo board)
% -------------------------------------------------------------------------

global Shandle;

% check to see if the board has that channel:
valPtr = libpointer('int32Ptr', 0);
calllib('phidget21', 'CPhidgetAdvancedServo_getMotorCount', Shandle, valPtr);
motorCount = get(valPtr, 'Value');
if(channel >= motorCount || channel < 0)
    if motorCount == 1
        fprintf(2,'ERROR in servoRun():  The Phidget 1066 board only supports channel 0.\n');
    else
        fprintf(2,'ERROR in servoRun():  The Phidget 1061 board only supports channels 0-7.\n');
    end
else
    calllib('phidget21', 'CPhidgetAdvancedServo_setEngaged', Shandle, channel, 1);
end