function [] = servoTarget(channel,position)
% -------------------------------------------------------------------------
% @ ver 1.0, Sept. 18, 2010, Jonathan P. Fiene, Univ. of Pennsylvania
% -------------------------------------------------------------------------
% Use this function to set the desired position for a particular servo
% channel.  Changes made while a servo is disabled will take effect as soon
% as the channel is enabled using servoRun().  Position values outside the
% range of a given servo will be ignored.
%
% -------------------------------------------------------------------------
% servoPos(channel, position)
%
% channel  = 0 (for the Phidget 1066 single-servo board)
%            0-7 (for the Phidget 1061 eight-servo board)
%
% position = desired position value
% -------------------------------------------------------------------------

global Shandle;

% check to see if the board has that channel:
valPtr = libpointer('int32Ptr', 0);
calllib('phidget21', 'CPhidgetAdvancedServo_getMotorCount', Shandle, valPtr);
motorCount = get(valPtr, 'Value');
if(channel >= motorCount || channel < 0)
    if motorCount == 1
        fprintf(2,'ERROR in servoTarget():  The Phidget 1066 board only supports channel 0.\n');
    else
        fprintf(2,'ERROR in servoTarget():  The Phidget 1061 board only supports channels 0-7.\n');
    end
else
    calllib('phidget21', 'CPhidgetAdvancedServo_setPosition', Shandle, channel, position);
end